==> openGion7.2.4.0_dev.zip: uap/webapps/gf/db/DERBY/sql/install/01_TABLE/GF05S.sql <==
/****************************************************************************/
/* GF05 ( ﾃｰﾌﾞﾙｶﾗﾑ定義 )                                                    */
/*                                                                          */
/* Created : 2018/09/28 16:03:47                                            */
/****************************************************************************/

CREATE TABLE GF05 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL                                                                                                        /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (    1 )                    NOT NULL                                                                                                        /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   VARCHAR (   50 )                    NOT NULL                                                                                                        /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR (   30 )                    NOT NULL                                                                                                        /*  40 項目         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL                                                                                                        /*  50 表示順       */
 , NAME_JA      VARCHAR (  200 )                                                                                                                                    /*  60 名称         */
 , CLS_NAME     VARCHAR (   10 )                    NOT NULL                                                                                                        /*  70 DBｸﾗｽ        */
 , USE_LENGTH   VARCHAR (    9 )        DEFAULT '0'                                                                                                                 /*  80 使用桁数     */
 , DATA_DEFAULT VARCHAR (  200 )                                                                                                                                    /*  90 初期値       */
 , NOT_NULL     VARCHAR (    1 )                                                                                                                                    /* 100 ﾉｯﾄﾇﾙ        */
 , KBCLM        VARCHAR (    1 )        DEFAULT '0' NOT NULL                                                                                                        /* 120 ｶﾗﾑ区分      */
 , RENDERER     VARCHAR (   10 )                                                                                                                                    /* 130 表示種別     */
 , EDITOR       VARCHAR (   10 )                                                                                                                                    /* 140 編集種別     */
 , DBTYPE       VARCHAR (   10 )                                                                                                                                    /* 150 文字種別     */
 , BIKO         VARCHAR ( 2000 )                                                                                                                                    /* 160 備考         */
 , CDKH         VARCHAR (    1 )                                                                                                                                    /* 170 改廃ｺｰﾄﾞ     */
 , UNIQ         BIGINT                              NOT NULL     generated always as identity (start with 1, increment by 1),constraint GF05 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                                                                                                                    /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                                                                                                                    /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                                                                                                                    /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                                                                                                                    /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                                                                                                                    /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                                                                                                                    /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                                                                                                                    /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                                                                                                                    /* 890 更新者       */
);

==> openGion7.2.9.4_dev.zip: uap/webapps/gf/db/DERBY/sql/install/01_TABLE/GF05S.sql <==
/****************************************************************************/
/* GF05 ( ﾃｰﾌﾞﾙｶﾗﾑ定義 )                                                    */
/*                                                                          */
/* Created : 2020/11/13 12:37:22                                            */
/****************************************************************************/

CREATE TABLE GF05 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL                                                                                                        /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (    1 )                    NOT NULL                                                                                                        /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   VARCHAR (   50 )                    NOT NULL                                                                                                        /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR (   30 )                    NOT NULL                                                                                                        /*  40 項目         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL                                                                                                        /*  50 表示順       */
 , NAME_JA      VARCHAR (  200 )                                                                                                                                    /*  60 名称         */
 , CLS_NAME     VARCHAR (   10 )                    NOT NULL                                                                                                        /*  70 DBｸﾗｽ        */
 , VIEW_LENGTH  VARCHAR (   10 )        DEFAULT '0'                                                                                                                 /*  80 表示桁数     */
 , USE_LENGTH   VARCHAR (    9 )        DEFAULT '0'                                                                                                                 /*  90 使用桁数     */
 , DATA_DEFAULT VARCHAR (  200 )                                                                                                                                    /* 100 初期値       */
 , NOT_NULL     VARCHAR (    1 )                                                                                                                                    /* 110 ﾉｯﾄﾇﾙ        */
 , KBCLM        VARCHAR (    1 )        DEFAULT '0' NOT NULL                                                                                                        /* 130 ｶﾗﾑ区分      */
 , RENDERER     VARCHAR (   10 )                                                                                                                                    /* 140 表示種別     */
 , EDITOR       VARCHAR (   10 )                                                                                                                                    /* 150 編集種別     */
 , DBTYPE       VARCHAR (   10 )                                                                                                                                    /* 160 文字種別     */
 , BIKO         VARCHAR ( 2000 )                                                                                                                                    /* 170 備考         */
 , CDKH         VARCHAR (    1 )                                                                                                                                    /* 180 改廃ｺｰﾄﾞ     */
 , UNIQ         BIGINT                              NOT NULL     generated always as identity (start with 1, increment by 1),constraint GF05 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                                                                                                                    /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                                                                                                                    /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                                                                                                                    /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                                                                                                                    /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                                                                                                                    /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                                                                                                                    /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                                                                                                                    /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                                                                                                                    /* 890 更新者       */
);
